package com.alicloud.openservices.tablestore.model;

import java.util.List;
import com.alicloud.openservices.tablestore.core.utils.Jsonizable;
import com.alicloud.openservices.tablestore.model.internal.TableOptionsEx;

public class DescribeTableResponse extends Response implements Jsonizable {
    /**
     * 表的Meta定义。
     */
    private TableMeta tableMeta;

    /**
     * 表的预留吞吐量的信息。
     */
    private ReservedThroughputDetails reservedThroughputDetails;

    /**
     * 表的配置参数。
     */
    private TableOptions tableOptions;

    /**
     * 
     */
    private List<PrimaryKey> shardSplits;

    /*
     * 内部接口。请勿使用。
     */
    public DescribeTableResponse(Response meta) {
        super(meta);
    }

    /**
     * 返回表的Meta定义。
     *
     * @return 表的Meta。
     */
    public TableMeta getTableMeta() {
        return tableMeta;
    }

    /*
     * 内部接口。请勿使用。
     */
    public void setTableMeta(TableMeta tableMeta) {
        this.tableMeta = tableMeta;
    }

    /**
     * 返回表的预留吞吐量的更改信息。
     *
     * @return 表的预留吞吐量的更改信息。
     */
    public ReservedThroughputDetails getReservedThroughputDetails() {
        return reservedThroughputDetails;
    }

    /**
     * 所有shard之间的分裂点。
     * 假设某表有两列pk，三个shard。则返回两个一列的分裂点，分别为A和B。
     * 三个shard的range分别为(-inf,-inf)->(A,-inf), (A,-inf)->(B,-inf), (B,-inf)->(+inf,+inf)
     */
    public List<PrimaryKey> getShardSplits() {
        return shardSplits;
    }

    public void setShardSplits(List<PrimaryKey> splits) {
        shardSplits = splits;
    }

    /*
     * 内部接口。请勿使用。
     */
    public void setReservedThroughputDetails(ReservedThroughputDetails reservedThroughputDetails) {
        this.reservedThroughputDetails = reservedThroughputDetails;
    }

    /**
     * 获取表的配置参数。
     *
     * @return 表的配置参数。
     */
    public TableOptions getTableOptions() {
        return tableOptions;
    }

    /*
     * 内部接口。请勿使用。
     */
    public void setTableOptions(TableOptionsEx tableOptions) {
        this.tableOptions = tableOptions;
    }

    @Override
    public String jsonize() {
        StringBuilder sb = new StringBuilder();
        jsonize(sb, "\n  ");
        return sb.toString();
    }

    @Override
    public void jsonize(StringBuilder sb, String newline) {
        sb.append('{');
        sb.append(newline);
        sb.append("\"TableMeta\": ");
        tableMeta.jsonize(sb, newline + "  ");
        sb.append(",");
        sb.append(newline);
        sb.append("\"ReservedThroughputDetails\": ");
        reservedThroughputDetails.jsonize(sb, newline + "  ");
        sb.append(",");
        sb.append(newline);
        sb.append("\"TableOptionsEx\": ");
        tableOptions.jsonize(sb, newline + "  ");
        sb.append('}');
    }
}
